@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[2]:
+# In[11]:
 
 
 ################################### Paquetes ######################################################
@@ -134,7 +134,7 @@ def grafico_histograma_sns(df,columna,option1,option2):
     plt.show() 
     
 def grafico_boxplot_jitted(df,columna,jit):
-    plt.rcParams['figure.figsize'] = (6,3)
+    plt.rcParams['figure.figsize'] = (9,4)
     red_cir = dict(markerfacecolor='r',marker='o',markersize=6)
     sns.set_style("whitegrid")
     
@@ -298,24 +298,6 @@ def Muestra_Total(A):
     return MuestraZOML
 
 
-# In[7]:
-
-
-int(1157/10)
-
-
-# In[9]:
-
-
-N=1159
-
-
-# In[10]:
-
-
-int(1159/10)
-
-
 # In[ ]:
 
 
